@@ -20,6 +20,7 @@ try:
     from .libs.docs.generate_docs import GenerateDocs
 except:pass
 from .libs.services import ServicesFindet
+from .libs import pytemplate
 from .base import BaseHandler, BaseModel
 from .handler.docshandler import DocsHandler
 
@@ -58,6 +59,7 @@ class App(tornado.web.Application):
         self.static_path = self.get_path(kwargs.get("static_path", "static"))
         self.handler_dir = self.get_path(kwargs.get("handler_dir", "handler"))
         self.model_dir = self.get_path(kwargs.get("model_dir", "model"))
+        self.testscript_dir = self.get_path(kwargs.get("testscript_dir", "test_script"))
         self.api_schema_dir = self.get_path(kwargs.get("api_schema_dir", "api_schema"))
         self.errors_dir = self.get_path(kwargs.get("errors_dir", "utils"))
         self.constant_dir = self.get_path(kwargs.get("constant_dir", "utils"))
@@ -80,11 +82,13 @@ class App(tornado.web.Application):
         self.create_base()
         self.create_handler()
         self.create_model()
+        self.create_test_cript()
         self.impmodule()
         self.handlers = route.get_routes(self.ROOT, self.handler_dir)
         # self.handlers.append((r'/docs', DocsHandler))
-        self.handlers.append(tornado.web.url(r'/docs/', DocsHandler, name=DocsHandler.__name__))
+        self.handlers.append(tornado.web.url(r'/docs', DocsHandler, name=DocsHandler.__name__))
         self.handlers.append(tornado.web.url(r'/.*', BaseHandler, name=BaseHandler.__name__))
+
         if not self.handlers:
             raise Exception("no api handler has been register.")
 
@@ -170,6 +174,24 @@ class App(tornado.web.Application):
 
         yaml2py.generate_resource_model_schema(self.model_schema_dir, self.api_schema_mp, self.jinja2_path_dir)
 
+    def create_test_cript(self):
+        """
+        create test restfull script
+        :return:
+        """
+        if not self.kwargs.get("generate_testscript", True):
+            return
+        test_init = utils.fix_path(os.path.join(self.testscript_dir, "__init__.py"))
+        if not os.path.exists(self.testscript_dir) or not os.path.exists(test_init):
+            if not os.path.exists(self.testscript_dir):
+                os.mkdir(self.testscript_dir)
+
+            if not os.path.exists(test_init):
+                with open(os.path.join(test_init), "w", encoding='utf-8') as p:
+                    p.write(pytemplate.get_testscript_init())
+
+        yaml2py.generate_resource_testscript(self.testscript_dir, self.api_schema_mp, self.jinja2_path_dir)
+
     def impmodule(self, model_dir=None):
         model_dir = model_dir or self.model_dir
         return yaml2py.impmodule(BaseModel, model_dir)
