@@ -111,7 +111,7 @@ class BaseHandler(RequestHandler):
                 logging.error("异常信息：" + error.message)
 
             logging.error("请求地址: %s %.2fms", self.request.uri, 1000.0 * self.request.request_time())
-            logging.error("请求参数: " + (json.dumps(utils.check2json(utils.pparams(self.request, params=self.params))) if hasattr(self, "params") else str(utils.pparams(self.request) or {})))
+            logging.error("请求参数: " + (json.dumps(utils.check2json(utils.pparams(self.request, params=self.source_params))) if hasattr(self, "source_params") else str(utils.pparams(self.request) or {})))
             if not hasattr(error, "code_name") or not hasattr(error, "code"):
                 return self.write_failed()
             else:
@@ -122,7 +122,7 @@ class BaseHandler(RequestHandler):
     def write_success(self, data=None):
         request_time = 1000.0 * self.request.request_time()
         is_slow_request = request_time > int(self.application.app_config["wsgi"].get("slow_request_time", 1000))
-        p = self.params if hasattr(self, "params") else {}
+        p = self.source_params if hasattr(self, "source_params") else None
         if is_slow_request:
             logging.warning("[%s] %d %s %.2fms", "慢请求", self.get_status(), self._request_summary(), request_time)
 
@@ -144,11 +144,15 @@ class BaseHandler(RequestHandler):
             self.write({"code": code, "msg": msg, "data": None})
             return
 
+    def write_html(self, template_name, **kwargs):
+        return self.render(template_name, **kwargs)
+
     def write(self, chunk):
         # from bson import json_util
         # chunk = json_util.dumps(chunk)
         chunk = utils.check2json(chunk)
-        chunk = json.dumps(chunk, ensure_ascii=False)
+        if isinstance(chunk, (dict, list, tuple)):
+            chunk = json.dumps(chunk, ensure_ascii=False)
         return super(BaseHandler, self).write(chunk)
 
     # def _request_summary(self):
