@@ -109,8 +109,7 @@ def get_fileinfo(file_data=None, file_path=None, require_format=[], require_size
         body = file_data["body"]
         filename = file_data["filename"]
         unique_name = utils.md5(body if isinstance(body, bytes) else body.encode("u8"))
-        name, format = file_data["filename"].rsplit(".", 1) if "." in file_data["filename"] else (
-        file_data["filename"], "")
+        name, format = file_data["filename"].rsplit(".", 1) if "." in file_data["filename"] else (file_data["filename"], "")
         # TODO Fix 包含有以下几种符号的文件名，会导致系统解压命令失败：'('、')'。如需在线调用系统命令解压，请打开注释.
         #  推荐使用python的Patool库进行统一加解压，可避免此问题
         # if format in ["rar", "zip", "pkg", "gz", "tar", "jar", "7z"]:
@@ -132,7 +131,7 @@ def get_fileinfo(file_data=None, file_path=None, require_format=[], require_size
     if require_format and format.lower() not in require_format:
         raise errors.UploadError("请上传指定格式：" + ",".join(require_format))
     if require_size and size > require_size:
-        raise errors.UploadError("大小不能超过%sM" % int(require_size / 1024 / 1024))
+        raise errors.UploadError("大小不能超过%sM" % int(require_size/1024/1024))
 
     return {
         "filename": filename,
@@ -150,7 +149,6 @@ def app(permission_bit=0):
     :param permission_bit:
     :return:
     """
-
     def wrap(method):
         @wraps(method)
         def has_role(self, *args, **kwargs):
@@ -171,7 +169,6 @@ def app(permission_bit=0):
 
     return wrap
 
-
 def admin(permission_bit=0):
     """
     管理后台验证: jtw
@@ -192,11 +189,11 @@ def admin(permission_bit=0):
                 token_debug = self.application.token_config.get("debug", False)
                 if not token_debug:
                     _check_token(self, permission_bit)
-
+                
                 # 用户后台
                 if self.request.headers.get("uid", None):
                     _check_admin(self)
-
+                
                 # 开发者接口方式访问
                 elif self.request.headers.get("appkey", None):
                     pass
@@ -279,13 +276,12 @@ def _check_admin(self):
 
     self.gid = self.member["gid"]
 
-
 def _check_token(self, permission_bit):
     if permission_bit != 0:
         if not self.uid or not self.token:
             raise errors.ErrorTokenInvalid
 
-        jwt = JWT.JwtToken(self.uid, self.application.token_config["secret"],
+        jwt = JWT.JwtToken(self.application.token_config["secret"],
                            self.application.token_config["expire"])
 
         # if self.application.token_config["secret"] in ["******"]:
@@ -306,6 +302,43 @@ def _check_token(self, permission_bit):
         except Exception as e:
             raise errors.ErrorTokenInvalid
 
+def check__forestall_brute(app, key):
+    """
+    防止暴力破解密码登录
+    登录前判断
+    """
+    if not hasattr(app, "forestall_brute_mapping"):
+        return True
+    else:
+        logs = app.forestall_brute_mapping.get(key, {"count": 0, "ts": 0})
+        if logs and logs["count"] >= 10 and logs.get("expire") > utils.now():
+            raise errors.ErrorInvalid("你的操作已被系统判定为攻击行为")
+        else:
+            return True
+
+def add_forestall_brute(app, key):
+    """
+    防止暴力破解密码登录
+    当密码错误后，将key加入规则
+    如次数得到指定值，将限定一段时间内不能登录
+    """
+    if not hasattr(app, "forestall_brute_mapping"):
+        setattr(app, "forestall_brute_mapping", {})
+    logs = app.forestall_brute_mapping.get(key, {"count": 0, "ts": 0})
+    logs["count"] += 1
+    logs["ts"] = utils.now()
+    if logs["count"] >= 10:
+        logs["expire"] = utils.now() + 15*60
+    app.forestall_brute_mapping[key] = logs
+
+def remove_forestall_brute(app, key):
+    """
+    防止暴力破解密码登录,以下操作后，移除key
+    登陆成功后
+    修改密码后
+    """
+    if hasattr(app, "forestall_brute_mapping"):
+        app.forestall_brute_mapping.pop(key, False)
 
 def verifi_sign(self, token, secret_key):
     """
@@ -527,11 +560,9 @@ def get_ua_client(ua):
     except:
         return 0
 
-
 def tts():
     return time.time() * 1000
 
-
 def get_argument(self):
     """
     ******
