@@ -1,6 +1,6 @@
 # coding=utf-8
 from functools import wraps
-
+from copy import deepcopy
 import re
 import types
 from lcyframe.libs import utils
@@ -21,7 +21,7 @@ def authorize(method):
 
 
 def _check_token(self):
-    jwt = JwtToken(self.uid, self.application.token_config["secret"], self.application.token_config["expire"])
+    jwt = JwtToken(self.application.token_config["secret"], self.application.token_config["expire"])
     try:
         if not jwt.is_validate(self.token):
             raise errors.ErrorTokenInvalid
@@ -271,6 +271,8 @@ def get_params(self, fill_default=True):
 
             p[params_name] = params_vaule
 
+    self.params = p
+    self.source_params = deepcopy(p)
     return p
 
 
