@@ -3,6 +3,7 @@
 import os
 import logging
 import tornado.web
+from lcyframe.libs import utils
 
 class route(object):
     _routes = []
@@ -23,7 +24,7 @@ class route(object):
             handler_dir = [handler_dir]
 
         for work in handler_dir:
-            for root, dirs, files in os.walk(os.path.join(ROOT, work)):
+            for root, dirs, files in os.walk(utils.fix_path(os.path.join(ROOT, work))):
                 for file in files:
                     if file.startswith("__"):
                         continue
