@@ -190,7 +190,7 @@ class ServicesFindet(object):
         if "secret" not in tc:
             raise Exception("you must give token secret in you setting.yml")
         self.__mount_attribute("token_config", tc)
-        self.__mount_attribute("Token", self._get_jwt(tc))
+        self.__mount_attribute("JwtToken", self._get_jwt(tc))
         return True
 
     def import_aes(self, config):
@@ -235,8 +235,9 @@ class ServicesFindet(object):
         :param p:
         :return:
         """
-
-        return functools.partial(self._token, config["secret"], config["expire"])
+        from .JWT import JwtToken
+        return JwtToken(config["secret"], int(config["expire"]))
+        # return functools.partial(self._token, config["secret"], config["expire"])
 
     def _token(self, secret, expire, uid):
         from .JWT import JwtToken
