@@ -15,6 +15,10 @@ from bson.objectid import ObjectId
 import operator
 import re
 import traceback
+import socket, requests
+from contextlib import suppress
+from urllib.parse import urlparse, urljoin
+from requests.utils import requote_uri
 try:
     from JWT import JwtToken
     from Rsa import RSA
@@ -204,7 +208,13 @@ def datetime2string(date, fmt="%Y-%m-%d %H:%M:%S"):
 
 def string2datetime(datestr, fmt="%Y-%m-%d %H:%M:%S"):
     """
+    datestr: 2022-06-29 14:58:27.047955
+    fmt: %Y-%m-%d %H:%M:%S
     2020-12-12 12:12:12 ==> datetime(2020,12,12 12:12:12)
+
+    datestr: 2022-06-29 14:58:27.047955
+    fmt: "%Y-%m-%d %H:%M:%S.%f
+    datetime(2022-06-29 14:58:27.047955)
     """
     return datetime.strptime(datestr, fmt)
 
@@ -241,15 +251,14 @@ def get_delta_day(day=0, is_zoo=False, return_fmt="date"):
     s5 = get_delta_day(return_fmt="%Y-%m-%d")
     s6 = get_delta_day(is_zoo=True)
     """
-    now = datetime.now()
 
     if is_zoo:
-        now_day = datetime.fromordinal(datetime.today().toordinal())
+        now = datetime.fromordinal(datetime.today().toordinal())
     else:
-        now_day = datetime.now()
+        now = datetime.now()
 
     if day == 0:
-        delta_day = now_day
+        delta_day = now
     else:
         # +-n天后
         delta_day = (now + timedelta(days=int(day)))
@@ -390,6 +399,147 @@ def check2json(data):
     else:
         return data
 
+def service_kill(name):
+    import subprocess
+    def cmdprocess(cmdline):
+        pipe = subprocess.Popen(cmdline, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE, close_fds=True)
+        output, stderr = pipe.communicate()
+        return_code = pipe.returncode
+        stderr = stderr.decode(errors='replace')
+        output = output.decode(errors='replace')
+        return output, stderr, return_code
+    try:
+        cmdline = "ps -ef | grep "+str(name)+" | grep -v grep | awk '{print $2}'"
+        output, stderr, return_code = cmdprocess(cmdline)
+        if return_code != 0:
+            return
+        pids = output.splitlines()
+        for pid in pids:
+            kill_cmdline = f"kill -9 {pid}"
+            cmdprocess(kill_cmdline)
+    except Exception as e:
+        logging.error(f'杀死进程{name}失败:{e}')
+
+def get_ip(address):
+    """
+    address：www.xxx.com
+    返回ip
+    """
+    with socket.socket(socket.AF_INET, socket.SOCK_DGRAM) as s:
+        with suppress(Exception):
+            s.connect((address, 1))
+            return s.getsockname()[0]
+    return None
+
+def ping(address, port):
+    test_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+    if test_socket.connect_ex((address, port)) == 0:
+        return True
+    else:
+        return False
+
+def check_dns(dns_host):
+    """
+    检测DNS服务器是否可用
+    """
+    is_enable = False
+    msg = b'\x5c\x6d\x01\x00\x00\x01\x00\x00\x00\x00\x00\x00\x03www\x05baidu\x03com\x00\x00\x01\x00\x01'
+    sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+    sock.settimeout(3)
+    for i in range(3):
+        sock.sendto(msg, (dns_host, 53))
+        try:
+            sock.recv(4096)
+            is_enable = True
+            break
+        except socket.timeout as e:
+            logging.error('{dns} 该dns服务器不可用'.format(dns=dns_host))
+
+    return is_enable
+
+def ip_into_int(ip):
+    from functools import reduce
+    return reduce(lambda x, y: (x << 8) + y, map(int, ip.split('.')))
+
+def check_internal_ip(ip):
+    """
+    内网IP
+    """
+    ip = ip_into_int(ip)
+    net_a = ip_into_int('10.255.255.255') >> 24
+    net_b = ip_into_int('172.31.255.255') >> 20
+    net_c = ip_into_int('192.168.255.255') >> 16
+    net_d = ip_into_int('127.0.0.0') >> 24
+    net_e = ip_into_int('0.0.0.0') >> 24
+    return ip >> 24 == net_a or ip >> 20 == net_b or ip >> 16 == net_c or ip >> 24 == net_d or ip >> 24 == net_e
+
+def check_ssrf_url(url):
+    """
+    提取有效url，防止SSRF攻击
+    URL为内网IP或域名，攻击者通过SSRF漏洞扫描内网漏洞获取权限
+    URL中包含端口，攻击者可以扫描发现内网其他机器的服务进行利用
+    当请求方法允许其他协议的时候，将可能利用gophar、file等协议进行第三方服务利用，如利用内网的redis获取权限、利用fastcgi进行getshell等
+    http://123.123.123.123@10.0.0.1:8888/
+    http://10.0.0.1#123.123.123.123
+    当request.get(url)时，实际请求10.0.0.1，存在安全隐患
+    """
+    schema = urlparse(url).scheme
+    hostname = urlparse(url).hostname
+    try:
+        if not verify_domain(url):
+            return ""
+        ip_address = socket.getaddrinfo(hostname, 'http')[0][4][0]
+        if check_internal_ip(ip_address):
+            return ""
+        return schema + "://" + hostname
+    except Exception as e:
+        return ""
+
+def safe_request_url(url, **kwargs):
+    """
+    安全请求外部url，防止SSRF攻击
+    1、通过内网ip攻击
+    2、通过30x状态码跳转攻击
+    3、通过误导访问不知名url攻击
+    """
+    def _request_check_location(r, *args, **kwargs):
+        if not r.is_redirect:
+            return
+        url = r.headers['location']
+
+        parsed = urlparse(url)
+        url = parsed.geturl()
+
+        # Facilitate relative 'location' headers, as allowed by RFC 7231.
+        # (e.g. '/path/to/resource' instead of 'http://domain.tld/path/to/resource')
+        # Compliant with RFC3986, we percent encode the url.
+        if not parsed.netloc:
+            url = urljoin(r.url, requote_uri(url))
+        else:
+            url = requote_uri(url)
+
+        safe_url = check_ssrf_url(url)
+        if not safe_url:
+            raise requests.exceptions.InvalidURL("SSRF Attack: %s" % (url, ))
+
+    safe_url = check_ssrf_url(url)
+    if not safe_url:
+        raise requests.exceptions.InvalidURL("SSRF Attack: %s" % (url,))
+
+    all_hooks = kwargs.get('hooks', dict())
+    if 'response' in all_hooks:
+        if hasattr(all_hooks['response'], '__call__'):
+            r_hooks = [all_hooks['response']]
+        else:
+            r_hooks = all_hooks['response']
+
+        r_hooks.append(_request_check_location)
+    else:
+        r_hooks = [_request_check_location]
+
+    all_hooks['response'] = r_hooks
+    kwargs['hooks'] = all_hooks
+    return requests.get(url, **kwargs)
 
 def verify_username(username, min: int = 4, max: int = 10):
     """
@@ -553,12 +703,12 @@ def extract_domain(domain):
     提取顶级域名
     domain: http://news.baidu.com
     tld = extract_domain(domain)
-    >>> ExtractResult(subdomain='news', domain='baidu', suffix='com')
-    >>> tld[0]
-    >>> tld[1]
-    >>> tld[2]
+        >>> ExtractResult(subdomain='news', domain='baidu', suffix='com')
+        >>> tld[0]
+        >>> tld[1]
+        >>> tld[2]
     tld.registered_domain
-    >>> baidu.com
+        >>> baidu.com
     """
     import tldextract
     tld = tldextract.extract(domain)
