@@ -10,6 +10,7 @@ from ruamel.yaml import round_trip_dump, round_trip_load, load, dump_all
 from importlib import import_module
 import inspect
 
+resource_mp = {}
 
 def impmodule(base, model_dir=None):
     """
@@ -104,19 +105,29 @@ def reduce_result_keys(result):
 
 def _filter_params(pkg_dir, schema, ignore_type=["bool", "BOOL"]):
     for f, item in schema["method"].items():
-        for params in item.get("parameters", []) or []:
+        parameters = item.get("parameters") or []
+        if type(parameters) != list:
+            raise Exception("parameters must is List. in %s:%s" % (pkg_dir, item["summary"]))
+        item["parameters"] = parameters
+
+        responses = item.get("responses") or {}
+        if responses is None:
+            raise Exception("parameters can not is None. in %s:%s" % (pkg_dir, item["summary"]))
+        item["responses"] = responses
+
+        for params in item["parameters"] or []:
             params_name = params["name"]
             for k, v in params.items():
                 if k == "type" and v.lower() in ignore_type:
-                    raise Exception("params '%s' can not is bool type in %s" % (params_name, pkg_dir))
+                    raise Exception("params '%s' can not is bool type in %s:%s" % (params_name, pkg_dir, item["summary"]))
 
             # if params["type"] == "json" and not params["required"] and params.get("default") is None:
             #     raise Exception(
             #         "params '%s' is json type. required true or give default in %s" % (params_name, pkg_dir))
 
-        for k, v in (item.get("responses", {}) or {}).items():
+        for k, v in item["responses"].items():
             if v is None:
-                raise Exception("responses key '%s' value can not is 'None' or empty in %s" % (k, pkg_dir))
+                raise Exception("responses key '%s' value can not is 'None' or empty in %s:%s" % (k, pkg_dir, item["summary"]))
 
 
 def dump_yaml_file(data, path, round_tripping=False):
@@ -177,7 +188,7 @@ def load_api_schema(api_schema_dir):
 
                 api = res["apis"]
                 if api in api_schema_mp:
-                    raise Exception("%s has multiple Api named '%s'; error" % (mod_name, api))
+                    raise Exception("%s has multiple Api named '%s'; error" % (mod_file_name, api))
 
                 if not model:
                     model = res.get("model", "")
@@ -209,7 +220,7 @@ def process_resource_context(model_path, resource_def):
     return resource_def
 
 
-def load_resource_handler(model_path, resource_text, jinja2_path=None):
+def load_jinja2_handler(model_path, resource_text, jinja2_path=None):
     template = load_jinja2("handler", jinja2_path)
 
     resources = []
@@ -221,7 +232,7 @@ def load_resource_handler(model_path, resource_text, jinja2_path=None):
     return s
 
 
-def load_resource_model(model_path, resource_text, jinja2_path=None):
+def load_jinja2_model(model_path, resource_text, jinja2_path=None):
     template = load_jinja2("model", jinja2_path)
 
     resources = []
@@ -233,7 +244,7 @@ def load_resource_model(model_path, resource_text, jinja2_path=None):
     return s
 
 
-def load_resource_model_schema(model_path, resource_text, jinja2_path=None):
+def load_jinja2_model_schema(model_path, resource_text, jinja2_path=None):
     template = load_jinja2("schema", jinja2_path)
 
     resources = []
@@ -244,6 +255,16 @@ def load_resource_model_schema(model_path, resource_text, jinja2_path=None):
     s = template.render(resources=resources)
     return s
 
+def load_jinja2_testscript(testscript_path, resource_text, jinja2_path=None):
+    template = load_jinja2("restfull", jinja2_path)
+
+    resources = []
+    for resource_def in resource_text:
+        resource_context = process_resource_context(testscript_path, resource_def)
+        resources.append(resource_context)
+
+    s = template.render(resources=resources)
+    return s
 
 def generate_resource_handler(handler_path, model_path, api_schema_mp, jinja2_path_dir):
     resource_mp = {}
@@ -257,7 +278,7 @@ def generate_resource_handler(handler_path, model_path, api_schema_mp, jinja2_pa
             logging.debug("handler [%s_handler.py] exists.. skip" % mod_name)
             continue
 
-        mod_py_source = load_resource_handler(model_path, item, jinja2_path_dir)
+        mod_py_source = load_jinja2_handler(model_path, item, jinja2_path_dir)
 
         with io.open(p, 'w', encoding='utf-8') as w:
             w.write(mod_py_source)
@@ -277,7 +298,7 @@ def generate_resource_model(model_path, api_schema_mp, jinja2_path_dir):
             logging.debug("model [%s_model.py] exists.. skip" % mod_name)
             continue
 
-        mod_py_source = load_resource_model(model_path, item, jinja2_path_dir)
+        mod_py_source = load_jinja2_model(model_path, item, jinja2_path_dir)
 
         with io.open(p, 'w', encoding='utf-8') as w:
             w.write(mod_py_source)
@@ -297,10 +318,28 @@ def generate_resource_model_schema(schema_path, api_schema_mp, jinja2_path_dir):
             logging.debug("schema [%s_schema.py] exists.. skip" % mod_name)
             continue
 
-        mod_py_source = load_resource_model_schema(schema_path, item, jinja2_path_dir)
+        mod_py_source = load_jinja2_model_schema(schema_path, item, jinja2_path_dir)
 
         with io.open(p, 'w', encoding='utf-8') as w:
             w.write(mod_py_source)
 
         logging.debug("schema [%s_schema.py] .. created success" % mod_name)
 
+def generate_resource_testscript(testscript_path, api_schema_mp, jinja2_path_dir):
+    resource_mp = {}
+    for api, item in api_schema_mp.items():
+        resource_mp.setdefault(item["name"], [])
+        resource_mp[item["name"]].append(item)
+
+    for mod_name, item in resource_mp.items():
+        p = os.path.join(testscript_path, mod_name + '.py')
+        if os.path.exists(p):
+            logging.debug("restfull script [%s.py] exists.. skip" % mod_name)
+            continue
+
+        mod_py_source = load_jinja2_testscript(testscript_path, item, jinja2_path_dir)
+
+        with io.open(p, 'w', encoding='utf-8') as w:
+            w.write(mod_py_source)
+
+        logging.debug("restfull script [%s.py] .. created success" % mod_name)
